pub enum ShaderCacheSource<'a> {
SpirV(&'a [u8]),
Wgsl(String),
Naga(Module),
}Expand description
Fully composed source code of a shader module, with all shader defs applied.
This is roughly equivalent to wgpu::ShaderSource,
but with less variants and more concrete types instead of Cow.
This source will be parsed and validated by the renderer.
Any necessary shader translation (e.g. from WGSL to SPIR-V or vice versa) must be done internally by the renderer.
Variants
SpirV(&'a [u8])
SPIR-V module represented as a slice of words.
Wgsl(String)
WGSL module as a string slice.
Naga(Module)
Naga module.