ShaderCache

Struct ShaderCache 

pub struct ShaderCache<ShaderModule, RenderDevice> { /* private fields */ }
A cache for shaders and shader imports, with asset state-tracking for waiting to load shaders until all imports are resolved.

Note that the RenderDevice generic parameter is a means by which to avoid a cyclic dependency with bevy_render, while also permitting alternative rendering implementations. The actual processing of the shader source into a usable compiled module is left to the renderer.

Implementations

Source

impl<ShaderModule, RenderDevice> ShaderCache<ShaderModule, RenderDevice>

pub fn new( device: RenderDevice, features: Features, downlevel: DownlevelFlags, load_module: fn(&RenderDevice, ShaderCacheSource<'_>, &ValidateShader) -> Result<ShaderModule, ShaderCacheError>, ) -> Self

Creates a new ShaderCache with the given features and shader module loading function. load_module is responsible for actually compiling shader source into a module usable by the render device.

pub fn get( &mut self, pipeline: CachedPipelineId, id: AssetId<Shader>, shader_defs: &[ShaderDefVal], ) -> Result<Arc<ShaderModule>, ShaderCacheError>

Attempts to retrieve or create a compiled shader module for the given shader id and shader definitions.

The provided pipeline is tracked so it may later be reported “dirty” when a shader is removed or replaced.

Note that the cache is keyed by id and shader_defs, meaning providing the same shader_defs in a different order, or with redundancies, will not result in cache hits, and thus require re-composing the module and calling load_module again.

pub fn set_shader( &mut self, id: AssetId<Shader>, shader: Shader, ) -> Vec<CachedPipelineId>

Inserts and possibly replaces a shader at the given asset id.

Returns a vec of which cached pipelines depended on it (directly or indirectly via a shader import) and thus must be recompiled.

pub fn remove(&mut self, id: AssetId<Shader>) -> Vec<CachedPipelineId>

Removes the shader with the given asset id.

Returns a vec of which cached pipelines depended on it (directly or indirectly via a shader import) and thus must be recompiled.