CachedPipelineId

Type Alias CachedPipelineId 

pub type CachedPipelineId = usize;
An id of a pipeline, typically in the PipelineCache Typically corresponds to a unique combination of Shader and ShaderDefVals.